@@ -75,24 +75,32 @@ LRT.trend <- function(x,sigma,number.of.bootstrap.samples=5000,confidence.level=
   r <- sweep(r,2,sigma,"*") + xbar
   L <- t(apply(r,1,LRT.value.trend,sigma=sigma))
   obsL <- LRT.value.trend(x,sigma)
-  cat(sprintf("In a test of the null hypothesis of equal proportions against the alternative that at least two are unequal, the p-value is %s.\n",format.pval(mean(obsL[3] <= L[,3]))))
+  options("scipen"=100)
+  cat(sprintf("In a test of the null hypothesis of equal proportions against the alternative that at least two are unequal, the p-value is %s.\n",format.pval(mean(obsL[3] <= L[,3]),eps=0.0001)))
   if(mean(obsL[3] <= L[,3]) < (1-confidence.level)){
     cat(sprintf("We reject the null hypothesis of equal proportions in favor of the alternative that at least two are unequal (at the %s%% level).\n\n",format(100*(1-confidence.level))))
   }else{
     cat(sprintf("We do not reject the null hypothesis of equal proportions (at the %s%% level).\n\n",format(100*(1-confidence.level))))
   }
-  cat(sprintf("In a test of the null hypothesis of equal proportions against the alternative of an increasing trend, the p-value is %s.\n",format.pval(mean(obsL[1] <= L[,1]))))
+  cat(sprintf("In a test of the null hypothesis of equal proportions against the alternative of a monotone trend (either up or down), the p-value is %s.\n",format.pval(mean(obsL[4] <= L[,4]),eps=0.0001)))
+  if(mean(obsL[4] <= L[,4]) < (1-confidence.level)){
+    cat(sprintf("We reject the null hypothesis of equal proportions in favor of the alternative of a monotone trend (at the %s%% level).\n\n",format(100*(1-confidence.level))))
+  }else{
+    cat(sprintf("We do not reject the null hypothesis of equal proportions (at the %s%% level).\n\n",format(100*(1-confidence.level))))
+  }
+  cat(sprintf("In a test of the null hypothesis of equal proportions against the alternative of an increasing trend, the p-value is %s.\n",format.pval(mean(obsL[1] <= L[,1]),eps=0.0001)))
   if(mean(obsL[1] <= L[,1]) < (1-confidence.level)){
     cat(sprintf("We reject the null hypothesis of equal proportions in favor of the alternative of an increasing trend (at the %s%% level).\n\n",format(100*(1-confidence.level))))
   }else{
     cat(sprintf("We do not reject the null hypothesis of equal proportions (at the %s%% level).\n\n",format(100*(1-confidence.level))))
   }
-  cat(sprintf("In a test of the null hypothesis of equal proportions against the alternative of an decreasing trend, the p-value is %s.\n",format.pval(mean(obsL[2] <= L[,2]))))
+  cat(sprintf("In a test of the null hypothesis of equal proportions against the alternative of an decreasing trend, the p-value is %s.\n",format.pval(mean(obsL[2] <= L[,2]),eps=0.0001)))
   if(mean(obsL[2] <= L[,2]) < (1-confidence.level)){
     cat(sprintf("We reject the null hypothesis of equal proportions in favor of the alternative of a decreasing trend (at the %s%% level).\n\n",format(100*(1-confidence.level))))
   }else{
     cat(sprintf("We do not reject the null hypothesis of equal proportions (at the %s%% level).\n\n",format(100*(1-confidence.level))))
   }
+#
   if("estimates" %in% plot){
     yminus <- x - 1.96*sigma
     yplus  <- x + 1.96*sigma
@@ -102,7 +110,7 @@ LRT.trend <- function(x,sigma,number.of.bootstrap.samples=5000,confidence.level=
   }
   if("distributions" %in% plot){
     binn <- 500
-    maxl <- max(1.1*obsL[3],quantile(L[,3],0.99))
+    maxl <- max(1.1*obsL[3],quantile(L[,3],0.95))
     r <- seq(0, maxl, length = binn + 1)[-1] - 0.5*maxl/binn
     yl <- locfit::locfit.raw(locfit::lp(L[,3],nn=0.1,h=0.8), xlim=c(0,maxl))
     gpdf <- predict(yl, newdata=r)
@@ -114,7 +122,7 @@ LRT.trend <- function(x,sigma,number.of.bootstrap.samples=5000,confidence.level=
      ylab="Density",
      xlab="Likelihood Ratio Statistic",main="Null Distribution of the Overall Test Statistic",sub="The vertical line is the observed statistic")
    abline(v=obsL[3],lty=2)
-    maxl <- max(1.1*obsL[1],quantile(L[,1],0.99))
+    maxl <- max(1.1*obsL[1],quantile(L[,1],0.95))
     r <- seq(0, maxl, length = binn + 1)[-1] - 0.5*maxl/binn
     yl <- locfit::locfit.raw(locfit::lp(L[,1],nn=0.1,h=0.8), xlim=c(0,maxl))
     gpdf <- predict(yl, newdata=r)
@@ -126,7 +134,7 @@ LRT.trend <- function(x,sigma,number.of.bootstrap.samples=5000,confidence.level=
      ylab="Density",
      xlab="Likelihood Ratio Statistic",main="Null Distribution of the Increasing Test Statistic",sub="The vertical line is the observed statistic")
    abline(v=obsL[1],lty=2)
-    maxl <- max(1.1*obsL[2],quantile(L[,2],0.99))
+    maxl <- max(1.1*obsL[2],quantile(L[,2],0.95))
     r <- seq(0, maxl, length = binn + 1)[-1] - 0.5*maxl/binn
     yl <- locfit::locfit.raw(locfit::lp(L[,2],nn=0.1,h=0.8), xlim=c(0,maxl))
     gpdf <- predict(yl, newdata=r)
@@ -138,6 +146,18 @@ LRT.trend <- function(x,sigma,number.of.bootstrap.samples=5000,confidence.level=
      ylab="Density",
      xlab="Likelihood Ratio Statistic",main="Null Distribution of the Decreasing Test Statistic",sub="The vertical line is the observed statistic")
    abline(v=obsL[2],lty=2)
+    maxl <- max(1.1*obsL[4],quantile(L[,4],0.95))
+    r <- seq(0, maxl, length = binn + 1)[-1] - 0.5*maxl/binn
+    yl <- locfit::locfit.raw(locfit::lp(L[,4],nn=0.1,h=0.8), xlim=c(0,maxl))
+    gpdf <- predict(yl, newdata=r)
+    scalef <- binn/sum(gpdf)
+    gpdf <- gpdf * scalef
+#   maxl <- r[which.max(cumsum(gpdf)>binn*0.99)]
+#  plot(density(L[,1]),xlim=c(0,max(obsL[1],quantile(L[,1],0.99))),
+   plot(x=r,y=gpdf,xlim=c(0,maxl), type="l",
+     ylab="Density",
+     xlab="Likelihood Ratio Statistic",main="Null Distribution of the Monotone Test Statistic",sub="The vertical line is the observed statistic")
+   abline(v=obsL[4],lty=2)
   }
   invisible(list(pvalue.increasing=mean(obsL[1] <= L[,1]),
        pvalue.decreasing=mean(obsL[2] <= L[,2]),
@@ -179,9 +199,11 @@ LRT.trend <- function(x,sigma,number.of.bootstrap.samples=5000,confidence.level=
 #' @keywords survey manip
 #' @examples
 #' 
+#' \donttest{
 #' x <- c(0.16,0.15,0.3)
 #' sigma <- c(0.04,0.04,0.1)
 #' LRT.value.trend(x,sigma)
+#' }
 #' @export 
 LRT.value.trend <- function(x,sigma){
   a <- 1/sigma^2
@@ -199,5 +221,110 @@ LRT.value.trend <- function(x,sigma){
   #LRT.decreasing <- sum(a*(x-xbar)^2)-sum(a*(x-m)^2)
   LRT.decreasing <- sum(a*(x-xbar)^2)-fit.ls2$fval
   LRT.overall <- sum(a*(x-xbar)^2)
-  return(c(LRT.increasing,LRT.decreasing,LRT.overall))
+  LRT.monotone <- sum(a*(x-xbar)^2)-min(fit.ls1$fval,fit.ls2$fval,na.rm=TRUE)
+  H0.monotone <- min(fit.ls1$fval,fit.ls2$fval,na.rm=TRUE)
+  H0.increasing <- fit.ls1$fval
+  H0.decreasing <- fit.ls2$fval
+  return(c(LRT.increasing,LRT.decreasing,LRT.overall,LRT.monotone,H0.increasing,H0.decreasing,H0.monotone))
+}
+#
+LRT.trend.null <- function(x,sigma,number.of.bootstrap.samples=5000,confidence.level=0.95,plot=NULL,seed=1,smooth=0.35){
+# require(isotone, quietly=TRUE, warn.conflicts=FALSE)
+# if(plot){
+#   suppressMessages(require(locfit, quietly = TRUE))
+# }
+  a <- 1/sigma^2
+  xbar <- sum(a*x)/sum(a)
+  k <- length(x)
+  set.seed(seed)
+  s <- seq_along(x)
+  Atot <- cbind(s[-length(s)], s[-1])
+  fit.ls1 <- isotone::activeSet(Atot, "LS", y = x, weights = a)
+  m.inc=fit.ls1$x
+  r <- matrix(rnorm(k*number.of.bootstrap.samples),ncol=k)
+  r <- sweep(r,2,sigma,"*") + m.inc
+  L.inc <- t(apply(r,1,LRT.value.trend,sigma=sigma))
+  Atot <- cbind(s[-1],s[-length(s)])
+  fit.ls2 <- isotone::activeSet(Atot, "LS", y = x, weights = a)
+  m.dec=fit.ls2$x
+  r <- matrix(rnorm(k*number.of.bootstrap.samples),ncol=k)
+  r <- sweep(r,2,sigma,"*") + m.dec
+  L.dec <- t(apply(r,1,LRT.value.trend,sigma=sigma))
+  L <- L.inc
+  L[,5] <- L.dec[,5]
+  L[,6] <- pmin(L.inc[,6],L.dec[,6])
+  obsL <- LRT.value.trend(x,sigma)
+#
+  options("scipen"=100)
+  cat(sprintf("In a test of the null hypothesis of an increasing trend in proportions against the complementary hypothesis, the p-value is %s.\n",format.pval(mean(obsL[4] <= L[,4]),eps=0.0001)))
+  if(mean(obsL[4] <= L[,4]) < (1-confidence.level)){
+    cat(sprintf("We reject the null hypothesis of an increasing trend (at the %s%% level).\n\n",format(100*(1-confidence.level))))
+  }else{
+    cat(sprintf("We do not reject the null hypothesis of an increasing trend (at the %s%% level).\n\n",format(100*(1-confidence.level))))
+  }
+  cat(sprintf("In a test of the null hypothesis of an decreasing trend in proportions against the complementary hypothesis, the p-value is %s.\n",format.pval(mean(obsL[5] <= L[,5]),eps=0.0001)))
+  if(mean(obsL[5] <= L[,5]) < (1-confidence.level)){
+    cat(sprintf("We reject the null hypothesis of an decreasing trend (at the %s%% level).\n\n",format(100*(1-confidence.level))))
+  }else{
+    cat(sprintf("We do not reject the null hypothesis of an decreasing trend (at the %s%% level).\n\n",format(100*(1-confidence.level))))
+  }
+  cat(sprintf("In a test of the null hypothesis of a monotone trend in proportions against the complementary hypothesis, the p-value is %s.\n",format.pval(mean(obsL[6] <= L[,6]),eps=0.0001)))
+  if(mean(obsL[6] <= L[,6]) < (1-confidence.level)){
+    cat(sprintf("We reject the null hypothesis of a monotone trend (at the %s%% level).\n\n",format(100*(1-confidence.level))))
+  }else{
+    cat(sprintf("We do not reject the null hypothesis of a monotone trend (at the %s%% level).\n\n",format(100*(1-confidence.level))))
+  }
+#
+#
+#
+  if("estimates" %in% plot){
+    yminus <- x - 1.96*sigma
+    yplus  <- x + 1.96*sigma
+    Hmisc::errbar(x=seq_along(x),y=x,yminus=yminus,
+     yplus=yplus,xlab="sequence",ylab="estimate",
+     main="Trend of estimates")
+  }
+  if("distributions" %in% plot){
+    binn <- 500
+    maxl <- max(1.1*obsL[6],quantile(L[,3],0.99))
+    r <- seq(0, maxl, length = binn + 1)[-1] - 0.5*maxl/binn
+    yl <- locfit::locfit.raw(locfit::lp(L[,6],nn=0.1,h=0.8), xlim=c(0,maxl))
+    gpdf <- predict(yl, newdata=r)
+    scalef <- binn/sum(gpdf)
+    gpdf <- gpdf * scalef
+#   maxl <- r[which.max(cumsum(gpdf)>binn*0.99)]
+#  plot(density(L[,6]),xlim=c(0,max(obsL[6],quantile(L[,6],0.99))),
+   plot(x=r,y=gpdf,xlim=c(0,maxl), type="l",
+     ylab="Density",
+     xlab="Likelihood Ratio Statistic",main="Null Distribution of the Overall Test Statistic",sub="The vertical line is the observed statistic")
+   abline(v=obsL[6],lty=2)
+    maxl <- max(1.1*obsL[4],quantile(L[,4],0.99))
+    r <- seq(0, maxl, length = binn + 1)[-1] - 0.5*maxl/binn
+    yl <- locfit::locfit.raw(locfit::lp(L[,4],nn=0.1,h=0.8), xlim=c(0,maxl))
+    gpdf <- predict(yl, newdata=r)
+    scalef <- binn/sum(gpdf)
+    gpdf <- gpdf * scalef
+#   maxl <- r[which.max(cumsum(gpdf)>binn*0.99)]
+#  plot(density(L[,4]),xlim=c(0,max(obsL[4],quantile(L[,4],0.99))),
+   plot(x=r,y=gpdf,xlim=c(0,maxl), type="l",
+     ylab="Density",
+     xlab="Likelihood Ratio Statistic",main="Null Distribution of the Increasing Test Statistic",sub="The vertical line is the observed statistic")
+   abline(v=obsL[4],lty=2)
+    maxl <- max(1.1*obsL[5],quantile(L[,5],0.99))
+    r <- seq(0, maxl, length = binn + 1)[-1] - 0.5*maxl/binn
+    yl <- locfit::locfit.raw(locfit::lp(L[,5],nn=0.1,h=0.8), xlim=c(0,maxl))
+    gpdf <- predict(yl, newdata=r)
+    scalef <- binn/sum(gpdf)
+    gpdf <- gpdf * scalef
+#   maxl <- r[which.max(cumsum(gpdf)>binn*0.99)]
+#  plot(density(L[,5]),xlim=c(0,max(obsL[5],quantile(L[,5],0.99))),
+   plot(x=r,y=gpdf,xlim=c(0,maxl), type="l",
+     ylab="Density",
+     xlab="Likelihood Ratio Statistic",main="Null Distribution of the Decreasing Test Statistic",sub="The vertical line is the observed statistic")
+   abline(v=obsL[5],lty=2)
+  }
+  invisible(list(pvalue.increasing=mean(obsL[1] <= L[,1]),
+       pvalue.decreasing=mean(obsL[2] <= L[,2]),
+       pvalue.overall=mean(obsL[3] <= L[,3]),
+       L=L,x=x,sigma=sigma))
 }
